<?php
/**
 * Custom template tags for technerd
 *
 * @package WordPress
 * @subpackage technerd
 * @since technerd 1.0
 */

/**
 * Custom Logo
 */

function technerd_the_custom_logo() {
	if ( function_exists( 'the_custom_logo' ) && function_exists( 'has_custom_logo' ) ) { 
		if ( has_custom_logo() ): ?>
			<div class='site-logo'>
				<?php the_custom_logo() ?>
			</div> 
	 	<?php
	 	elseif ( is_front_page() && is_home() ) : ?>
			<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
		<?php else : ?>
			<span class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></span>
		<?php endif; 
	}
}

/* How about an author bio template tag? Let's do it! */

if ( ! function_exists( 'technerd_author_bio' ) ) {
	function technerd_author_bio() {
		?>
		<div class="author-info clearfix">
			<div class="author-image">
				<a href="<?php echo esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ); ?>"><?php echo get_avatar( get_the_author_meta('user_email'), '100', '' ); ?></a>
			</div>   
			<div class="author-bio">
				<h4><a href="<?php echo esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ); ?>"><?php the_author(); ?></a></h4>
				<p><?php the_author_meta('description'); ?></p>
			</div>
		</div>
		<?php
	}
}

/**
 * Social Icons. Used in header.php, probably!
 */

function technerd_social_icon( $site ) {

  $url = get_theme_mod( $site . '_url' );

  if ( $url != NULL) {
    echo '<a class="social-icon" title="' . $site . '" href="' . esc_url( $url ) . '"><i class="fa fa-' . $site . '"></i></a>';
  } else {
  	return NULL;
  }
}

/** 
 * Flexslider template tag
 */

function technerd_flexslider() {

	$enabled = get_theme_mod( 'enable_slider' );
	$stickies = get_option( 'sticky_posts' );
	$count = count( $stickies );

	$args = array(
	    'post__in' => $stickies,
	    'posts_per_page' => 10,
	    'post_type' => 'post',
	    'nopaging' => true
	    );

	$query = new WP_Query( $args );

	if ( $enabled ) {
		if ( $count > 0 ) : 
			echo '<div class="flexslider-wrapper"><div class="flexslider clearfix">';
			  echo '<ul class="slides">';

		    	while ( $query->have_posts() ) : $query->the_post();
			      
			      echo '<li><a href="'. get_permalink() .'">';
			      
			      if ( (function_exists( 'has_post_thumbnail' )) && ( has_post_thumbnail() ) ) :
			        echo get_the_post_thumbnail();
			      endif;

		        echo '<div class="flex-caption">';
		            if ( get_the_title() != '' ) echo '<h2 class="entry-title">'. get_the_title().'</h2>';
		            if ( get_the_excerpt() != '' ) echo '<div class="excerpt">' . get_the_excerpt() .'</div>';
		        echo '</div>';
		        echo '</a></li>';
	        endwhile;
			  echo '</ul>';
			echo '</div></div>';
		endif;
	}
}
