<?php
/**
 * The main template file
 *
 * This is the most generic template file in a WordPress theme
 * and one of the two required files for a theme (the other being style.css).
 * It is used to display a page when nothing more specific matches a query.
 * e.g., it puts together the home page when no home.php file exists.
 *
 * Learn more: {@link https://codex.wordpress.org/Template_Hierarchy}
 *
 * @package technerd
 * @since technerd 1.0
 */

get_header(); ?>

<main id="main" class="site-main container" role="main">
	<div class="main-content">

	  <?php 
		if ( is_front_page() && !is_paged() ): 
		  technerd_flexslider();
		endif;
	  ?>

		<?php if ( have_posts() ) : 

			// Start the loop.
			while ( have_posts() ) : the_post(); 
		  
				/*
				 * Include the Post-Format-specific template for the content.
				 * If you want to override this in a child theme, then include a file
				 * called content-___.php (where ___ is the Post Format name) and that will be used instead.
				 */
				get_template_part('content', get_post_format()); 

				if ( comments_open() || '0' != get_comments_number() ) :
					comments_template();
				endif; 
				
			// End the loop.
	  	endwhile; 

			// Previous/next page navigation.
			the_posts_pagination( array(
				'mid_size' 					 => 2,
				'prev_text'          => __( 'Previous', 'technerd' ),
				'next_text'          => __( 'Next', 'technerd' ),
			) );

	  // If no content, display no posts found message.
		else: 
	  	_e('No posts were found. Sorry!', 'technerd'); 
		endif; ?>
	</div><!-- .main-content -->

	<div class="right-sidebar">
		<?php get_sidebar(); ?>
	</div><!-- .right-sidebar -->

</main><!-- .site-main -->
	
<?php get_footer(); ?>
